@@ -13,18 +13,6 @@ import asyncio
 
 typer_app = typer.Typer(name="Shoestring Assembler", no_args_is_help=True)
 
-
-@typer_app.command()
-def check_recipe(
-    recipe_location: Annotated[
-        str, typer.Argument(help="Path to recipe file")
-    ] = "./recipe.toml",
-):
-    Display.print_top_header("Checking Recipe")
-    Recipe.load(recipe_location)
-    Display.print_top_header("Finished")
-
-
 @typer_app.command()
 def download(
     verbose: Annotated[
@@ -32,7 +20,7 @@ def download(
     ] = False,
 ):
     """
-    Downloads the specified solution
+    Download a new solution 
     """
     execute(Action.DOWNLOAD, verbose=verbose)
 
@@ -69,7 +57,7 @@ def update(
 
 @typer_app.command()
 def assemble(
-    recipe_location: Annotated[
+    recipe: Annotated[
         str, typer.Argument(help="Path to recipe file")
     ] = "./recipe.toml",
     download: bool = True,
@@ -82,7 +70,7 @@ def assemble(
     """
     execute(
         Action.ASSEMBLE,
-        recipe_location=recipe_location,
+        recipe_location=recipe,
         verbose=verbose,
         download=download,
     )
@@ -97,31 +85,78 @@ def reconfigure(
         bool, typer.Option("--verbose", help="Show extra logs.")
     ] = False,
 ):
+    """
+    Generates configuration files based on user input.
+    """
     execute(Action.RECONFIGURE, recipe_location=recipe_location, verbose=verbose)
 
 
 @typer_app.command()
 def build():
+    """
+    Builds the solution's docker images
+    """
     execute(Action.BUILD)
 
 
 @typer_app.command()
 def setup():
+    """
+    Runs setup scripts for containers that have them
+    """
     execute(Action.SETUP)
 
 
 @typer_app.command()
 def start():
+    """
+    Starts the solution
+    """
     execute(Action.START)
 
 
 @typer_app.command()
 def stop():
+    """
+    Stops the solution
+    """
     execute(Action.STOP)
 
 
+@typer_app.command()
+def restart():
+    """
+    Stops, rebuilds, and starts the solution
+    """
+    execute(Action.RESTART)
+
+
+@typer_app.command()
+def check_recipe(
+    recipe: Annotated[
+        str, typer.Argument(help="Path to recipe file")
+    ] = "./recipe.toml",
+):
+    """
+    Validates the provided recipe file
+    """
+    Display.print_top_header("Checking Recipe")
+
+    loop = asyncio.get_event_loop()
+    check_task = loop.create_task(Recipe.load(recipe))
+    try:
+        loop.run_until_complete(check_task)
+        Display.print_complete("Recipe is valid")
+        Display.print_top_header("Finished")
+    except asyncio.CancelledError:
+        Display.print_error("Failed")
+
+
 @typer_app.command()
 def logs(service: Annotated[str, typer.Option(help="Service to log")] = None):
+    """
+    Shows the logs for the solution or a specific service if specified
+    """
     from shoestring_assembler.engine.action.docker import Docker
     from shoestring_assembler.model.solution import SolutionModel
 
@@ -129,13 +164,11 @@ def logs(service: Annotated[str, typer.Option(help="Service to log")] = None):
     Docker.logs(solution_model, service)
 
 
-@typer_app.command()
-def restart():
-    execute(Action.RESTART)
-
-
 @typer_app.command()
 def app():
+    """
+    Runs the interactive CLI application
+    """
     from shoestring_assembler.view.cli_app import SolutionAssemblerApp
 
     app = SolutionAssemblerApp()
