@@ -16,7 +16,7 @@ from pathlib import Path
 import yaml
 import json
 import datetime
-
+import asyncio
 
 # TODO - look at --progress json tag for all operations - when not affected by bug
 
@@ -112,6 +112,7 @@ class Docker:
                 if err_line:
                     await Update.SuccessMsg(f"{err_line}")
 
+            await asyncio.sleep(0) # yield
             process.poll()
 
         process.wait()
@@ -141,12 +142,20 @@ class Docker:
                     command.extend(setup_cmd)
                 else:
                     command.append(setup_cmd)
-                # process = subprocess.run(command, capture_output=False)
-                process = subprocess.Popen(
-                    command, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, stdin= subprocess.PIPE
+
+                process = await asyncio.create_subprocess_exec(
+                    *command,
+                    stdin=asyncio.subprocess.PIPE,
+                    stdout=asyncio.subprocess.PIPE,
+                    stderr=asyncio.subprocess.STDOUT,
                 )
 
-                await handle_setup_process(process)
+                try:
+                    await handle_async_setup_process(process)
+                except asyncio.CancelledError:  # ensure subprocess is terminated on task cancellation
+                    process.kill()
+                    await process.wait()
+                    raise
 
                 if process.returncode == 0:
                     await Update.InfoMsg(f"{service_name} - Setup Successful")
@@ -247,103 +256,31 @@ class Docker:
         except json.JSONDecodeError:
             return None
 
-
-def reader_thread(stdout_pipe, output_queue):
-    """
-    Reads data from the subprocess's stdout and places it in a queue.
-    This prevents the main thread from blocking on a read call.
-    """
-    try:
-        out_buffer = bytearray()
-        while True:
-            out_line = None
-            char = stdout_pipe.read(1)
-            if char == b"\n":
-                out_line = out_buffer.decode()
-                out_buffer.clear()
-            elif char:
-                out_buffer += char
-            else:
-                # end of file
-                break
-
-            if out_line:
-                output_queue.put(out_line)
-    except Exception as e:
-        print(f"Reader thread error: {e}")
-
-
-# A thread to write to the subprocess's stdin
-def writer_thread(stdin_pipe, input_queue):
-    """
-    Reads messages from an input queue and writes them to the subprocess's stdin.
-    This allows the main thread to send messages without blocking.
-    """
-    try:
-        while True:
-            # Use get(block=True) to wait for a message
-            message = input_queue.get()
-            if message is None:  # Use a sentinel value to signal termination
-                break
-            stdin_pipe.write(f"{message}\n".encode())
-            stdin_pipe.flush()
-    except Exception as e:
-        print(f"Writer thread error: {e}")
-
-
-import threading
-import queue
-
-async def handle_setup_process(process: subprocess.Popen):
-    # Queues for inter-thread communication
-    input_queue = queue.Queue()  # For sending messages to the writer thread
-    output_queue = queue.Queue()  # For receiving messages from the reader thread
-
-    # Create and start the I/O threads
-    reader = threading.Thread(target=reader_thread, args=(process.stdout, output_queue))
-    writer = threading.Thread(target=writer_thread, args=(process.stdin, input_queue))
-
-    reader.daemon = (
-        True  # Allows the main program to exit even if the thread is still running
-    )
-    writer.daemon = True
-
-    reader.start()
-    writer.start()
-
+async def handle_async_setup_process(process: asyncio.subprocess.Process):
     while process.returncode == None:
+        response = await process.stdout.readline()
         try:
-            # Use a non-blocking get to check if the queue has data
-            response = output_queue.get(block=False)
-            try:
-                payload = json.loads(response)
-                match payload.get("type"):
-                    case "input":
-                        response = await Input.make_request(payload)
-                        if response is not None:
-                            input_queue.put(response)
-                    case "output":
-                        message = payload.get("message")
-                        match payload.get("variant"):
-                            case "heading":
-                                await Update.StepHeading(message)
-                            case "error":
-                                await Update.ErrorMsg(message)
-                            case "success":
-                                await Update.SuccessMsg(message)
-                            case _:
-                                await Update.InfoMsg(message)
-                    case _:
-                        print("NO TYPE")
-            except json.JSONDecodeError:
-                await Update.InfoMsg(response.strip())
-
-        except queue.Empty:
-            # No data available, continue doing other work
-            pass
-        process.poll()
-
-    input_queue.put(None)  # Signal the writer thread to terminate
+            payload = json.loads(response)
+            match payload.get("type"):
+                case "input":
+                    response = await Input.make_request(payload)
+                    if response is not None:
+                        process.stdin.write((response + "\n").encode())                        
+                case "output":
+                    message = payload.get("message")
+                    match payload.get("variant"):
+                        case "heading":
+                            await Update.StepHeading(message)
+                        case "error":
+                            await Update.ErrorMsg(message)
+                        case "success":
+                            await Update.SuccessMsg(message)
+                        case _:
+                            await Update.InfoMsg(message)
+                case _:
+                    print("NO TYPE")
+        except json.JSONDecodeError:
+            await Update.InfoMsg(response.decode().strip())
 
 
 async def parse_docker_json_progress(process: subprocess.Popen, callback):
@@ -404,7 +341,8 @@ async def parse_docker_json_progress(process: subprocess.Popen, callback):
                         await callback(line_content)
                 except:
                     await Update.ErrorMsg(err_line)
-
+        
+        await asyncio.sleep(0)  # yield
         process.poll()
 
     process.wait()
