@@ -48,7 +48,10 @@ class UserConfig:
         sm.user_config.version = sm.user_config.template.version
 
         # write answers
-        sm.user_config.prev_answers = sm.user_config.answers
+        sm.user_config.prev_answers = sm.user_config.answer_context
+        await Update.DebugLog(
+            f"Saved answers for {sm.name} - {sm.user_config.answer_context}"
+        )
 
 
 """
