@@ -2,6 +2,7 @@ from ._events import EventPipe
 from .audit import Audit, AuditEvent
 from .progress import Progress, ProgressEvent, ProgressSection
 from .updates import FatalError, Update
+from .input import Input
 
 __all__ = {
     EventPipe,
@@ -12,4 +13,5 @@ __all__ = {
     ProgressEvent,
     FatalError,
     ProgressSection,
+    Input,
 }
