@@ -29,4 +29,4 @@ class EventPipe:
     async def __call_callback(self, event):
         if self.__callback is not None:
             await self.__callback(event)
-            await asyncio.sleep(0)
+            await asyncio.sleep(0)  # yield
