@@ -78,12 +78,15 @@ class ProgressSection:
 class ProgressBar:
     def __init__(self, label, total, current, callback, detail_level):
         self.total = total
-        self.current = current
+        self.current = current if isinstance(current, int) else 0
         self.label = label
         self.callback = callback
         self.detail_level = detail_level
 
     async def update(self, value):
+        if not isinstance(value, int):
+            await Update.DebugLog(f"ProgressBar.update() called with non-int value: {value} on {self.label}")
+            value = 0
         self.current = value
         await self.callback()
 
