@@ -20,6 +20,8 @@ class Action(Enum):
     START = "start"
     STOP = "stop"
     RESTART = "restart"
+    EDIT = "edit"
+    REMOVE = "remove"
 
 
 class ActionSignal(Signal):
