@@ -209,13 +209,16 @@ class UserConfig:
         Returns a merged dict of template defaults and previous answers.
         Preference is given to previous answers
         """
+        val = {**self.template.defaults, **self.prev_answers}
         return {**self.template.defaults, **self.prev_answers}
 
     @property
-    def context(self):
-        return self.template.prompts.generate_outputs({**self.prompt_defaults,**self.answers})
-    
-    
+    def answer_context(self):
+        return {**self.prompt_defaults, **self.answers}
+
+    @property
+    def context(self):  # file gen context
+        return self.template.prompts.generate_outputs(self.answer_context)
 
 
 class Version(tuple):
