@@ -15,6 +15,7 @@ from shoestring_assembler.interface.state_machine import steps
 
 from shoestring_assembler.interface.events.updates import FatalError
 from shoestring_assembler.engine.engine import Engine
+from textual.worker import WorkerCancelled
 
 
 class SolutionAssemblerApp(App):
@@ -136,4 +137,19 @@ class SolutionAssemblerApp(App):
             # display error modal and then quit
             self.push_screen(screens.FatalErrorModal(error_message=fatal_error.message))
 
+        self.action_quit()
+
+    # overload to add cleanup
+    async def action_quit(self) -> None:
+        """An [action](/guide/actions) to quit the app as soon as possible."""
+        self.engine_worker.cancel()
+        try:
+            await self.engine_worker.wait()
+        except WorkerCancelled:
+            pass
+        self.monitor_worker.cancel()
+        try:
+            await self.monitor_worker.wait()
+        except WorkerCancelled:
+            pass
         self.exit()
