@@ -114,7 +114,7 @@ class ServiceModuleEntry(VerticalScroll):
             yield Label("No user config prompts for this service module")
             return
 
-        prompts.start(name, user_config.answers)
+        prompts.start(name, user_config.answer_context)
         Display.print_debug(f"Initialising Prompts: {prompts}")
         while question := prompts.next():
             Display.print_debug(
@@ -148,6 +148,20 @@ class ServiceModuleEntry(VerticalScroll):
                         question_prompt=question.prompt,
                         value=str(real_value),
                     )
+                case Question.Bool():
+                    default_value = user_config.prompt_defaults.get(question.key)
+                    answer_value = user_config.answers.get(question.key)
+                    real_value = (
+                        answer_value
+                        if answer_value is not None
+                        else default_value if default_value is not None else False
+                    )
+
+                    yield BoolQuestion(
+                        question_id=question.id,
+                        question_prompt=question.prompt,
+                        value=real_value,
+                    )
 
     def fix_focus(self):
         if self.last_changed:
@@ -188,6 +202,18 @@ class ServiceModuleEntry(VerticalScroll):
         # Audit.submit("text_input", Audit.Type.Expected, key=prompt_id, value=value)
         self.last_changed = prompt_id
 
+    @on(Button.Pressed)
+    def handle_button_press(self, message: Button.Pressed):
+        prompt_id = message.button.id
+        value = message.button.variant == "error"
+
+        prompt = self.service_module.user_config.template.prompts.get(prompt_id)
+        self.service_module.user_config.answers[prompt.key] = value
+
+        self.last_changed = prompt_id
+        self.refresh_flag = not self.refresh_flag
+        self.call_after_refresh(self.fix_focus)
+
 
 class SelectQuestion(VerticalGroup):
 
@@ -265,3 +291,37 @@ class TextQuestion(VerticalGroup):
     def compose(self):
         yield Label(self.question_prompt)
         yield Input(value=self.value, id=self.question_id)
+
+
+class BoolQuestion(VerticalGroup):
+
+    def __init__(
+        self,
+        *children,
+        question_prompt="",
+        value=None,
+        question_id=None,
+        name=None,
+        id=None,
+        classes=None,
+        disabled=False,
+        markup=True,
+    ):
+        super().__init__(
+            *children,
+            name=name,
+            id=id,
+            classes=classes,
+            disabled=disabled,
+            markup=markup,
+        )
+        self.question_prompt = question_prompt
+        self.value = value
+        self.question_id = question_id
+
+    def compose(self):
+        yield Label(self.question_prompt)
+        text = "Yes" if self.value == True else "No"
+        variant = "success" if self.value == True else "error"
+
+        yield Button(text, variant=variant, id=self.question_id)
