@@ -228,10 +228,11 @@ class PromptWrapper(HorizontalGroup):
 
 
 class StageLog(VerticalScroll):
-    contents = reactive({}, recompose=True)
+    refresh_flag = reactive(bool, recompose=True)
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.contents = {}
         self.id_counter = 0
         self.select_options = {}
 
@@ -328,13 +329,13 @@ class StageLog(VerticalScroll):
     @on(Select.Changed)
     def handle_select_changed(self, event: Select.Changed):
         self.select_options[event.select.name] = event.value
-        
+
     @on(Button.Pressed, ".select_button")
     def handle_select_pressed(self, event: Button.Pressed):
         key = event.button.name
         if key in self.select_options:
             self.handle_input_result(key, self.select_options[key])
-    
+
     @on(Button.Pressed, ".continue_button")
     def handle_continue_pressed(self, event: Button.Pressed):
         self.handle_input_result(event.button.name, "continue")
@@ -361,7 +362,7 @@ class StageLog(VerticalScroll):
 
     def clear(self):
         self.contents = {}
-        self.mutate_reactive(StageLog.contents)
+        self.refresh_flag = not self.refresh_flag
 
     def set_progress(self):
         # import time
@@ -377,12 +378,12 @@ class StageLog(VerticalScroll):
 
     def handle_progress_update(self, event: ProgressEvent):
         self.contents[event.key] = event
-        self.mutate_reactive(StageLog.contents)
+        self.refresh_flag = not self.refresh_flag
 
     def add_update(self, event):
         self.contents[f"{self.id_counter}"] = event
         self.id_counter += 1
-        self.mutate_reactive(StageLog.contents)
+        self.refresh_flag = not self.refresh_flag
 
 
 class LogSection(VerticalGroup):
