@@ -229,8 +229,8 @@ class PlainCLI:
                     if prompt_list is None:
                         pass
                     else:
-                        prompt_list.start("", user_config.answers)
-                        while question := prompt_list.next(user_config.answers):
+                        prompt_list.start("", user_config.answer_context)
+                        while question := prompt_list.next(user_config.answer_context):
                             match question:
                                 case Question.Select():
                                     default_value = user_config.prompt_defaults.get(
@@ -268,6 +268,18 @@ class PlainCLI:
                                         f"\[answered] {result}", log_level=5
                                     )
                                     user_config.answers[question.key] = result
+                                case Question.Bool():
+                                    result = Prompt.ask(
+                                        question.prompt,
+                                        choices=["y", "n"],
+                                        default="y" if user_config.prompt_defaults.get(
+                                            question.key
+                                        ) else "n"
+                                    )
+                                    Display.print_log(
+                                        f"\[answered] {result}", log_level=5
+                                    )
+                                    user_config.answers[question.key] = result
                 return "continue"
 
             case steps.PromptNoRecipe():
